==> xlniux-client-1.0.1-20141016.100933-1-sources.jar: com/xunlei/niux/client/jinzuan/dto/MemberShipDTO.java <==
package com.xunlei.niux.client.jinzuan.dto;

import com.xunlei.niux.data.jinzuan.vo.PrivilegeReceiveInfo;

import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * User: admin
 * Date: 14-3-10
 * Time: 下午3:11
 * To change this template use File | Settings | File Templates.
 */
public class MemberShipDTO {
    private Long seqId;
    private Long userId;
    private Long growthValue;
    private Long levelGrowthValue;
    private Long nextLevelGrowthValue;
    private Integer levelNum;
    private Integer memberStatus;
    private Integer isAnnualMember;
    private String registerTime;
    private String lastFeeTime;
    private String annualMemberExpireDate;
    private String memberExpireDate;

    private List<PrivilegeReceiveInfoDTO> prilist;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getGrowthValue() {
        return growthValue;
    }

    public void setGrowthValue(Long growthValue) {
        this.growthValue = growthValue;
    }

    public Long getLevelGrowthValue() {
        return levelGrowthValue;
    }

    public void setLevelGrowthValue(Long levelGrowthValue) {
        this.levelGrowthValue = levelGrowthValue;
    }

    public Long getNextLevelGrowthValue() {
        return nextLevelGrowthValue;
    }

    public void setNextLevelGrowthValue(Long nextLevelGrowthValue) {
        this.nextLevelGrowthValue = nextLevelGrowthValue;
    }

    public Integer getIsAnnualMember() {
        return isAnnualMember;
    }

    public void setIsAnnualMember(Integer isAnnualMember) {
        this.isAnnualMember = isAnnualMember;
    }

    public Integer getLevelNum() {
        return levelNum;
    }

    public void setLevelNum(Integer levelNum) {
        this.levelNum = levelNum;
    }

    public Integer getMemberStatus() {
        return memberStatus;
    }

    public void setMemberStatus(Integer memberStatus) {
        this.memberStatus = memberStatus;
    }

    public Integer getAnnualMember() {
        return isAnnualMember;
    }

    public void setAnnualMember(Integer annualMember) {
        isAnnualMember = annualMember;
    }

    public String getRegisterTime() {
        return registerTime;
    }

    public void setRegisterTime(String registerTime) {
        this.registerTime = registerTime;
    }

    public String getLastFeeTime() {
        return lastFeeTime;
    }

    public void setLastFeeTime(String lastFeeTime) {
        this.lastFeeTime = lastFeeTime;
    }

    public String getAnnualMemberExpireDate() {
        return annualMemberExpireDate;
    }

    public void setAnnualMemberExpireDate(String annualMemberExpireDate) {
        this.annualMemberExpireDate = annualMemberExpireDate;
    }

    public String getMemberExpireDate() {
        return memberExpireDate;
    }

    public void setMemberExpireDate(String memberExpireDate) {
        this.memberExpireDate = memberExpireDate;
    }

    public List<PrivilegeReceiveInfoDTO> getPrilist() {
        return prilist;
    }

    public void setPrilist(List<PrivilegeReceiveInfoDTO> prilist) {
        this.prilist = prilist;
    }

    @Override
    public String toString() {
        return "MemberShipDTO{" +
                "seqId=" + seqId +
                ", userId=" + userId +
                ", growthValue=" + growthValue +
                ", levelGrowthValue=" + levelGrowthValue +
                ", nextLevelGrowthValue=" + nextLevelGrowthValue +
                ", levelNum=" + levelNum +
                ", memberStatus=" + memberStatus +
                ", isAnnualMember=" + isAnnualMember +
                ", registerTime='" + registerTime + '\'' +
                ", lastFeeTime='" + lastFeeTime + '\'' +
                ", annualMemberExpireDate='" + annualMemberExpireDate + '\'' +
                ", memberExpireDate='" + memberExpireDate + '\'' +
                ", prilist=" + prilist +
                '}';
    }
}

==> xlniux-client-1.0.4-20141021.084728-3-sources.jar: com/xunlei/niux/client/jinzuan/dto/MemberShipDTO.java <==
package com.xunlei.niux.client.jinzuan.dto;

import java.util.List;

/**
 * Created with IntelliJ IDEA.
 * User: admin
 * Date: 14-3-10
 * Time: 下午3:11
 * To change this template use File | Settings | File Templates.
 */
public class MemberShipDTO {
    private Long seqId;
    private Long userId;
    private Long growthValue;
    private Long levelGrowthValue;
    private Long nextLevelGrowthValue;
    private Integer levelNum;
    private Integer memberStatus;
    private Integer isAnnualMember;
    private String registerTime;
    private String lastFeeTime;
    private String annualMemberExpireDate;
    private String memberExpireDate;

    //体验金钻
    private Integer experienceStatus;
    private String experienceDate;
    private String lastExperienceTime;

    private List<PrivilegeReceiveInfoDTO> prilist;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getGrowthValue() {
        return growthValue;
    }

    public void setGrowthValue(Long growthValue) {
        this.growthValue = growthValue;
    }

    public Long getLevelGrowthValue() {
        return levelGrowthValue;
    }

    public void setLevelGrowthValue(Long levelGrowthValue) {
        this.levelGrowthValue = levelGrowthValue;
    }

    public Long getNextLevelGrowthValue() {
        return nextLevelGrowthValue;
    }

    public void setNextLevelGrowthValue(Long nextLevelGrowthValue) {
        this.nextLevelGrowthValue = nextLevelGrowthValue;
    }

    public Integer getIsAnnualMember() {
        return isAnnualMember;
    }

    public void setIsAnnualMember(Integer isAnnualMember) {
        this.isAnnualMember = isAnnualMember;
    }

    public Integer getLevelNum() {
        return levelNum;
    }

    public void setLevelNum(Integer levelNum) {
        this.levelNum = levelNum;
    }

    public Integer getMemberStatus() {
        return memberStatus;
    }

    public void setMemberStatus(Integer memberStatus) {
        this.memberStatus = memberStatus;
    }

    public Integer getAnnualMember() {
        return isAnnualMember;
    }

    public void setAnnualMember(Integer annualMember) {
        isAnnualMember = annualMember;
    }

    public String getRegisterTime() {
        return registerTime;
    }

    public void setRegisterTime(String registerTime) {
        this.registerTime = registerTime;
    }

    public String getLastFeeTime() {
        return lastFeeTime;
    }

    public void setLastFeeTime(String lastFeeTime) {
        this.lastFeeTime = lastFeeTime;
    }

    public String getAnnualMemberExpireDate() {
        return annualMemberExpireDate;
    }

    public void setAnnualMemberExpireDate(String annualMemberExpireDate) {
        this.annualMemberExpireDate = annualMemberExpireDate;
    }

    public String getMemberExpireDate() {
        return memberExpireDate;
    }

    public void setMemberExpireDate(String memberExpireDate) {
        this.memberExpireDate = memberExpireDate;
    }

    public List<PrivilegeReceiveInfoDTO> getPrilist() {
        return prilist;
    }

    public void setPrilist(List<PrivilegeReceiveInfoDTO> prilist) {
        this.prilist = prilist;
    }

    public Integer getExperienceStatus() {
        return experienceStatus;
    }

    public void setExperienceStatus(Integer experienceStatus) {
        this.experienceStatus = experienceStatus;
    }

    public String getExperienceDate() {
        return experienceDate;
    }

    public void setExperienceDate(String experienceDate) {
        this.experienceDate = experienceDate;
    }

    public String getLastExperienceTime() {
        return lastExperienceTime;
    }

    public void setLastExperienceTime(String lastExperienceTime) {
        this.lastExperienceTime = lastExperienceTime;
    }

    @Override
    public String toString() {
        return "MemberShipDTO{" +
                "seqId=" + seqId +
                ", userId=" + userId +
                ", growthValue=" + growthValue +
                ", levelGrowthValue=" + levelGrowthValue +
                ", nextLevelGrowthValue=" + nextLevelGrowthValue +
                ", levelNum=" + levelNum +
                ", memberStatus=" + memberStatus +
                ", isAnnualMember=" + isAnnualMember +
                ", registerTime='" + registerTime + '\'' +
                ", lastFeeTime='" + lastFeeTime + '\'' +
                ", annualMemberExpireDate='" + annualMemberExpireDate + '\'' +
                ", memberExpireDate='" + memberExpireDate + '\'' +
                ", prilist=" + prilist +
                '}';
    }
}
